﻿/* Helpers.cs
 * part of zaaReloaded2
 * 
 * Copyright 2015-2017 Daniel Kraus
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
using System;

namespace zaaReloaded2
{
    /// <summary>
    /// Common helper methods.
    /// </summary>
    public static class Helpers
    {
        /// <summary>
        /// Splits a text into paragraphs.
        /// </summary>
        /// <param name="paragraph">Text to split.</param>
        /// <returns>Array of paragraphs in the text.</returns>
        /// <remarks>
        /// This implementation relies on the fact that the order of
        /// splitting strings in C#'s String.Split() method is
        /// important; see http://stackoverflow.com/a/8664639/270712
        /// </remarks>
        public static string[] SplitParagraphs(string text)
        {
            return text.Split(
                new string[] { "\r\n", "\n\r", "\r", "\n" },
                StringSplitOptions.RemoveEmptyEntries);
        }

        /// <summary>
        /// Starts a custom undo record.
        /// </summary>
        /// <param name="message"></param>
        public static void StartUndo(string message)
        {
            if (Globals.ThisAddIn != null)
            {
                Globals.ThisAddIn.Application.UndoRecord.StartCustomRecord(
                    String.Format("{0} ({1})", message, Properties.Settings.Default.AddinName)
                    );
            }
        }

        /// <summary>
        /// Ends an undo record.
        /// </summary>
        public static void EndUndo()
        {
            if (Globals.ThisAddIn != null)
            {
                Globals.ThisAddIn.Application.UndoRecord.EndCustomRecord();
            }
        }
    }
}
