﻿/* ZaaImporter.cs
 * part of zaaReloaded2
 * 
 * Copyright 2015-2017 Daniel Kraus
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Linq;
using System.Text;
using Bovender.Extensions;
using zaaReloaded2.LabModel;
using zaaReloaded2.Thesaurus;

namespace zaaReloaded2.Importer.ZaaImporter
{
    /// <summary>
    /// Imports laboratory items by parsing the Lauris data from a
    /// physician's letter.
    /// </summary>
    public class ZaaImporter : BaseImporter
    {
        #region Constructor

        public ZaaImporter() : base() { }

        #endregion

        #region Implementation of BaseImporter

        protected override TimePoint CreateTimePoint(string paragraph, Parameters parameters, Units units)
        {
            return new LaurisTimePoint(paragraph, parameters, units);
        }

        protected override bool IsTimeStamp(string paragraph)
        {
            return LaurisTimePoint.IsTimeStampLine(paragraph);
        }

        protected override bool IsItemsParagraph(string paragraph)
        {
            return LaurisParagraph.ResemblesLaurisParagraph(paragraph);
        }

        #endregion

        #region Class logger

        private static NLog.Logger Logger { get { return _logger.Value; } }

        private static readonly Lazy<NLog.Logger> _logger = new Lazy<NLog.Logger>(() => NLog.LogManager.GetCurrentClassLogger());

        #endregion
    }
}
